<?php
/**
 * WHMCS PayPlantation Module
 *
 * PayPlantation Payment Gateway modules allow you to integrate payment solutions with the
 * WHMCS platform.
 *
 *
 * For more information, please refer to the online documentation.
 *
 * @see https://payplantation.com/plugins.php
 *
 * @copyright Copyright (c) PayPlantation Limited 2015
 */

if (!defined("WHMCS")) {
    die("This file cannot be accessed directly");
}
define('BASE_URL', 'https://payplantation.com/gateway/');
function payplantation_MetaData()
{
    return array(
        'DisplayName' => 'PayPlantation Payment Gateway Module',
        'APIVersion' => '1.1', // Use API Version 1.1
        'DisableLocalCreditCardInput' => true,
        'TokenisedStorage' => false,
    );
}

function payplantation_config()
{
    return array(
        // the friendly display name for a payment gateway should be
        // defined here for backwards compatibility
        'FriendlyName' => array(
            'Type' => 'System',
            'Value' => 'PayPlantation Payment Gateway Module',
        ),
        // a text field type allows for single line text input
        'clientID' => array(
            'FriendlyName' => 'PayPlantation Client ID',
            'Type' => 'text',
            'Size' => '50',
            'Default' => '',
            'Description' => 'Get your API credentials from PayPlantation.',
        ),
        // a password field type allows for masked text input
        'secretKey' => array(
            'FriendlyName' => 'PayPlantation Client Secret',
            'Type' => 'password',
            'Size' => '50',
            'Default' => '',
            'Description' => 'Get your API credentials from PayPlantation.',
        ),
    );
}


function payplantation_link($params)
{
 
        // Gateway Configuration Parameters
        $client_id = $params['clientID'];
        $client_secret = $params['secretKey'];
  
        // Invoice Parameters
        $invoiceId = $params['invoiceid'];
        $description = $params["description"];
        $amount = $params['amount'];
        $currencyCode = $params['currency'];
    
        // Client Parameters
        $firstname = $params['clientdetails']['firstname'];
        $lastname = $params['clientdetails']['lastname'];
        $email = $params['clientdetails']['email'];
        $address1 = $params['clientdetails']['address1'];
        $address2 = $params['clientdetails']['address2'];
        $city = $params['clientdetails']['city'];
        $state = $params['clientdetails']['state'];
        $postcode = $params['clientdetails']['postcode'];
        $country = $params['clientdetails']['country'];
        $phone = $params['clientdetails']['phonenumber'];
    
        // System Parameters
        $companyName = $params['companyname'];
        $systemUrl = $params['systemurl'];
        $returnUrl = $params['returnurl'];

        $callback_url = $systemUrl . '/modules/gateways/callback/payplantation.php?order_id='.$invoiceId.'&token=';
        $return_url = $returnUrl;
        $req['payer']     = 'payplantation';
        $req['amount']    = $amount;
        $req['currency']  = $currencyCode;
        $req['successUrl'] = $callback_url;
        $req['cancelUrl'] = $return_url;
        
        try {
            
          $token= payplantation_getAccessToken($client_id,$client_secret);
          $responce = payplantation_sendTransactionInfo($token,$req);
          $form = '<script>
                     location.replace("'.$responce.'")
                   </script>';
            
        }
        catch (\Exception $ex)
        {
           
          $form = $ex->getMessage();
         
        }
     
     return $form;

}
function payplantation_getAccessToken($client_id,$client_secret)
    {
        $payload['client_id']     = $client_id;
        $payload['client_secret'] = $client_secret;

        $res = payplantation_execute(BASE_URL . 'api/merchant/verify', 'post', $payload);
        $res = json_decode($res);

        if (!$res)
        { 
            throw new Exception('Please check you client iD or client secret again');
            exit;
        }

        if ($res->status == 'error')
        {
            $error = $res->message;
            throw new Exception($error);
            exit;
        }
        $response = $res->data->access_token;

        return $response;
    }
 function payplantation_sendTransactionInfo($token,$req)
    {

        $header = ['Authorization: Bearer ' . $token];

        $res = payplantation_execute(BASE_URL . 'api/merchant/transaction-info', 'POST', $req, $header);
        $res = json_decode($res);

        if (!$res)
        {
            throw new Exception('Please check your transaction details again !');
            exit;
        }

        if ($res->status == 'error')
        {
            throw new Exception($res->message);
            exit;
        }

        $response = $res->data->approvedUrl;
        return $response;
    }

 function  payplantation_execute($url, $method, $payload, $headers = null)
    {
        $ch = curl_init();
        curl_setopt_array($ch, array(
            CURLOPT_URL            => $url,
            CURLOPT_RETURNTRANSFER => true,
            CURLOPT_FOLLOWLOCATION => true,
        ));
        if (strtoupper($method) == "POST")
        {
            curl_setopt($ch, CURLOPT_POST, true);
            curl_setopt($ch, CURLOPT_POSTFIELDS, $payload);
        }
        if ($headers != null)
        {
            curl_setopt($ch, CURLOPT_HTTPHEADER, $headers);
        }

        $result = curl_exec($ch);
        $info   = curl_getinfo($ch, CURLINFO_HEADER_OUT);
  
        curl_close($ch);
        return $result;
    }

?>
